# AncillaryInfoFeature

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | [**FeatureType**](FeatureType.md) |  | 
**geometry** | [**GeoJSONGeometry**](GeoJSONGeometry.md) |  | 
**properties** | [**AncillaryInfoProperties**](AncillaryInfoProperties.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

